// Filename: pystub.cxx
// Created by:  drose (09Aug00)
//
////////////////////////////////////////////////////////////////////
//
// PANDA 3D SOFTWARE
// Copyright (c) 2001 - 2004, Disney Enterprises, Inc.  All rights reserved
//
// All use of this software is subject to the terms of the Panda 3d
// Software license.  You should have received a copy of this license
// along with this source code; you will also find a current copy of
// the license at http://etc.cmu.edu/panda3d/docs/license/ .
//
// To contact the maintainers of this program write to
// panda3d-general@lists.sourceforge.net .
//
////////////////////////////////////////////////////////////////////

#include "pystub.h"

extern "C" {
  EXPCL_DTOOLCONFIG int PyArg_ParseTuple(...);
  EXPCL_DTOOLCONFIG int PyErr_Occurred(...);
  EXPCL_DTOOLCONFIG int PyErr_SetString(...);
  EXPCL_DTOOLCONFIG int PyExc_TypeError(...);
  EXPCL_DTOOLCONFIG int PyDict_GetItem(...);
  EXPCL_DTOOLCONFIG int PyFloat_AsDouble(...);
  EXPCL_DTOOLCONFIG int PyFloat_FromDouble(...);
  EXPCL_DTOOLCONFIG int PyFloat_Type(...);
  EXPCL_DTOOLCONFIG int PyInt_AsLong(...);
  EXPCL_DTOOLCONFIG int PyInt_FromLong(...);
  EXPCL_DTOOLCONFIG int PyInt_Type(...);
  EXPCL_DTOOLCONFIG int PyList_Append(...);
  EXPCL_DTOOLCONFIG int PyList_AsTuple(...);
  EXPCL_DTOOLCONFIG int PyList_New(...);
  EXPCL_DTOOLCONFIG int PyLong_AsLongLong(...);
  EXPCL_DTOOLCONFIG int PyLong_AsUnsignedLong(...);
  EXPCL_DTOOLCONFIG int PyLong_AsUnsignedLongLong(...);
  EXPCL_DTOOLCONFIG int PyLong_FromLongLong(...);
  EXPCL_DTOOLCONFIG int PyLong_FromUnsignedLong(...);
  EXPCL_DTOOLCONFIG int PyLong_FromUnsignedLongLong(...);
  EXPCL_DTOOLCONFIG int PyLong_Type(...);
  EXPCL_DTOOLCONFIG int PyNumber_Long(...);
  EXPCL_DTOOLCONFIG int PyObject_CallObject(...);
  EXPCL_DTOOLCONFIG int PyObject_Call(...);
  EXPCL_DTOOLCONFIG int PyObject_Free(...);
  EXPCL_DTOOLCONFIG int PyObject_GetAttrString(...);
  EXPCL_DTOOLCONFIG int PyObject_HasAttrString(...);
  EXPCL_DTOOLCONFIG int PyObject_IsInstance(...);
  EXPCL_DTOOLCONFIG int PyObject_IsTrue(...);
  EXPCL_DTOOLCONFIG int PyObject_SetAttrString(...);
  EXPCL_DTOOLCONFIG int PyObject_Str(...);
  EXPCL_DTOOLCONFIG int PySequence_Check(...);
  EXPCL_DTOOLCONFIG int PySequence_GetItem(...);
  EXPCL_DTOOLCONFIG int PySequence_Size(...);
  EXPCL_DTOOLCONFIG int PySequence_Tuple(...);
  EXPCL_DTOOLCONFIG int PyString_AsString(...);
  EXPCL_DTOOLCONFIG int PyString_AsStringAndSize(...);
  EXPCL_DTOOLCONFIG int PyString_FromString(...);
  EXPCL_DTOOLCONFIG int PyString_FromStringAndSize(...);
  EXPCL_DTOOLCONFIG int PyString_Type(...);
  EXPCL_DTOOLCONFIG int PyTuple_GetItem(...);
  EXPCL_DTOOLCONFIG int PyTuple_New(...);
  EXPCL_DTOOLCONFIG int PyType_IsSubtype(...);
  EXPCL_DTOOLCONFIG int PyUnicode_Type(...);
  EXPCL_DTOOLCONFIG int PyUnicodeUCS2_FromWideChar(...);
  EXPCL_DTOOLCONFIG int PyUnicodeUCS4_FromWideChar(...);
  EXPCL_DTOOLCONFIG int Py_BuildValue(...);
  EXPCL_DTOOLCONFIG int Py_InitModule4(...);
  EXPCL_DTOOLCONFIG int PyCFunction_New(...);
  EXPCL_DTOOLCONFIG int PyCFunction_NewEx(...);
  EXPCL_DTOOLCONFIG int PyDict_SetItemString(...);
  EXPCL_DTOOLCONFIG int PyDict_SetItem(...);
  EXPCL_DTOOLCONFIG int PyObject_GenericSetAttr(...);
  EXPCL_DTOOLCONFIG int PyType_GenericAlloc(...);
  EXPCL_DTOOLCONFIG int PyModule_AddObject(...);
  EXPCL_DTOOLCONFIG int _PyObject_Del(...);
  EXPCL_DTOOLCONFIG int PyDict_New(...);
  EXPCL_DTOOLCONFIG int PyErr_Clear(...);
  EXPCL_DTOOLCONFIG int PyType_Ready(...);
  EXPCL_DTOOLCONFIG int PyTuple_Type(...);
  EXPCL_DTOOLCONFIG int PyErr_Format(...);
  EXPCL_DTOOLCONFIG int PyTuple_Size(...);
  EXPCL_DTOOLCONFIG int PyModule_AddIntConstant(...);
  EXPCL_DTOOLCONFIG int PyObject_GenericGetAttr(...);
  EXPCL_DTOOLCONFIG int PyArg_Parse(...);
  EXPCL_DTOOLCONFIG int PyDict_Type(...);
  EXPCL_DTOOLCONFIG int PyArg_ParseTupleAndKeywords(...);
  EXPCL_DTOOLCONFIG int PyDict_Size(...);
  EXPCL_DTOOLCONFIG int Py_InitModule4TraceRefs(...);
  EXPCL_DTOOLCONFIG int _PyObject_DebugFree(...);
  EXPCL_DTOOLCONFIG int _Py_Dealloc(...);
  EXPCL_DTOOLCONFIG int _Py_RefTotal(...);
  EXPCL_DTOOLCONFIG int _Py_NegativeRefcount(...);

  EXPCL_DTOOLCONFIG extern void *PyExc_AssertionError;
  EXPCL_DTOOLCONFIG extern void *_Py_NoneStruct;
  EXPCL_DTOOLCONFIG extern void *_Py_NotImplementedStruct;
};


int PyArg_ParseTupleAndKeywords(...) { return 0; }
int PyDict_Size(...){ return 0; }
int PyArg_ParseTuple(...) { return 0; }
int PyErr_Occurred(...) { return 0; }
int PyErr_SetString(...) { return 0; }
int PyExc_TypeError(...) { return 0; }
int PyDict_GetItem(...) { return 0; }
int PyFloat_AsDouble(...) { return 0; }
int PyFloat_FromDouble(...) { return 0; }
int PyFloat_Type(...) { return 0; }
int PyInt_AsLong(...) { return 0; }
int PyInt_FromLong(...) { return 0; }
int PyInt_Type(...) { return 0; }
int PyList_Append(...) { return 0; }
int PyList_AsTuple(...) { return 0; }
int PyList_New(...) { return 0; }
int PyLong_AsLongLong(...) { return 0; }
int PyLong_AsUnsignedLong(...) { return 0; }
int PyLong_AsUnsignedLongLong(...) { return 0; }
int PyLong_FromLongLong(...) { return 0; }
int PyLong_FromUnsignedLong(...) { return 0; }
int PyLong_FromUnsignedLongLong(...) { return 0; }
int PyLong_Type(...) { return 0; }
int PyNumber_Long(...) { return 0; }
int PyObject_CallObject(...) { return 0; }
int PyObject_Call(...) { return 0; }
int PyObject_Free(...) { return 0; }
int PyObject_GetAttrString(...) { return 0; }
int PyObject_HasAttrString(...) { return 0; }
int PyObject_IsInstance(...) { return 0; }
int PyObject_IsTrue(...) { return 0; }
int PyObject_SetAttrString(...) { return 0; }
int PyObject_Str(...) { return 0; }
int PySequence_Check(...) { return 0; }
int PySequence_GetItem(...) { return 0; }
int PySequence_Size(...) { return 0; }
int PySequence_Tuple(...) { return 0; }
int PyString_AsString(...) { return 0; }
int PyString_AsStringAndSize(...) { return 0; }
int PyString_FromString(...) { return 0; }
int PyString_FromStringAndSize(...) { return 0; }
int PyString_Type(...) { return 0; }
int PyTuple_GetItem(...) { return 0; }
int PyTuple_New(...) { return 0; }
int PyType_IsSubtype(...) { return 0; }
int PyUnicode_Type(...) { return 0; }
int PyUnicodeUCS2_FromWideChar(...) { return 0; }
int PyUnicodeUCS4_FromWideChar(...) { return 0; }
int Py_BuildValue(...) { return 0; }
int Py_InitModule4(...) { return 0; }
int PyCFunction_New(...) { return 0; };
int PyCFunction_NewEx(...) { return 0; };
int PyDict_SetItemString(...) { return 0; };
int PyDict_SetItem(...) { return 0; };
int PyObject_GenericSetAttr(...) { return 0; };
int PyType_GenericAlloc(...) { return 0; };
int PyModule_AddObject(...) { return 0; };
int _PyObject_Del(...) { return 0; };
int PyDict_New(...) { return 0; };
int PyErr_Clear(...) { return 0; };
int PyType_Ready(...) { return 0; };
int PyTuple_Type(...) { return 0; };
int PyErr_Format(...) { return 0; };
int PyTuple_Size(...) { return 0; };
int PyModule_AddIntConstant(...) { return 0; };
int PyObject_GenericGetAttr(...) { return 0; };
int PyArg_Parse(...) { return 0; };
int PyDict_Type(...) { return 0; };
int Py_InitModule4TraceRefs(...) { return 0; };
int _PyObject_DebugFree(...) { return 0; };
int _Py_Dealloc(...) { return 0; };
int _Py_RefTotal(...) { return 0; };
int _Py_NegativeRefcount(...) { return 0; };



void *PyExc_AssertionError = (void *)NULL;
void *_Py_NoneStruct = (void *)NULL;
void *_Py_NotImplementedStruct = (void *)NULL;


void
pystub() {
}
